Adds panels (such as Panel A, Panel B,...) to the regression tables.
add_panels(
regression_table,
num_panels,
bold = FALSE,
italic = TRUE,
latex_gap_space = "0.5cm",
panel_labels,
rows_per_model,
hline_after = FALSE
)the regression table to be given panels to.
the number of panels in the regression table. Passed in from panelsummary.
whether the panel labels should be bold or not.
whether the panel labels should be in italics.
the amount of space between the two panels. This is the optimal spacing.
the text to come after each Panel A:... and Panel B:...
the number of rows in each of the panels.
whether to add a horizontal line after each Panel