Learn R Programming

panelsummary (version 0.1.2.1)

change_to_lists: Changes all models passed into panelsummary into a list

Description

Changes all models passed into panelsummary into a list

Usage

change_to_lists(models)

Value

A list of lists. It will change any non-list component to a list.

Arguments

models

Input list. This is the input list of models taken from the user.