get_lpanel_fe: gets the number of fixed effects in the last panel for...

View source: R/helper_functions.R

get_lpanel_feR Documentation

gets the number of fixed effects in the last panel for collapse_fe purposes

Description

gets the number of fixed effects in the last panel for collapse_fe purposes

Usage

get_lpanel_fe(df, panels)

panelsummary documentation built on March 20, 2026, 9:07 a.m.