Learn R Programming

panelsummary (version 0.1.2.1)

get_panel_indices: gets the row numbers for break points in the panels

Description

gets the row numbers for break points in the panels

Usage

get_panel_indices(panel)

Arguments