get_panel_indices_collapse: gets the indices of each of the breaks in the panel

View source: R/helper_functions.R

get_panel_indices_collapseR Documentation

gets the indices of each of the breaks in the panel

Description

gets the indices of each of the breaks in the panel

Usage

get_panel_indices_collapse(panel_df, num_panels)

panelsummary documentation built on March 20, 2026, 9:07 a.m.