remove_fe: removes all fixed effects except the final panel (for...

View source: R/helper_functions.R

remove_feR Documentation

removes all fixed effects except the final panel (for collapse_fe)

Description

removes all fixed effects except the final panel (for collapse_fe)

Usage

remove_fe(panel_df, num_panels)

panelsummary documentation built on March 20, 2026, 9:07 a.m.