shift_means: shifts the custom glance means to above observations and...

View source: R/helper_functions.R

shift_meansR Documentation

shifts the custom glance means to above observations and renames

Description

shifts the custom glance means to above observations and renames

Usage

shift_means(df)

panelsummary documentation built on March 20, 2026, 9:07 a.m.