powered by
Changes all models passed into panelsummary into a list
change_to_lists(models)
A list of lists. It will change any non-list component to a list.
Input list. This is the input list of models taken from the user.