Learn R Programming

panelsummary (version 0.1.2.1)

get_lpanel_fe: gets the number of fixed effects in the last panel for collapse_fe purposes

Description

gets the number of fixed effects in the last panel for collapse_fe purposes

Usage

get_lpanel_fe(df, panels)

Arguments