`get_means_fixest` generates the mean of the dependent variable for each model supplied to the panelsummary::panelsummary. This function only accepts fixest objects as it uses built-in fixest fitstat to compute the means.
get_means_fixest(models, fmt)A list of named vectors denoting the means of each model.
A list of lists. Each list should contain fixest objects.
An integer. This will denote how many decimal places to round to for the table.