Learn R Programming

panelsummary (version 0.1.2.1)

get_panel_indices_collapse: gets the indices of each of the breaks in the panel

Description

gets the indices of each of the breaks in the panel

Usage

get_panel_indices_collapse(panel_df, num_panels)

Arguments