Learn R Programming

panelsummary (version 0.1.2.1)

panelsummary-package: panelsummary: Create Publication-Ready Regression Tables with Panels

Description

Create an automated regression table that is well-suited for models that are estimated with multiple dependent variables. 'panelsummary' extends 'modelsummary' (Arel-Bundock, V. (2022) tools:::Rd_expr_doi("10.18637/jss.v103.i01")) by allowing regression tables to be split into multiple sections with a simple function call. Utilize familiar arguments such as fmt, estimate, statistic, vcov, conf_level, stars, coef_map, coef_omit, coef_rename, gof_map, and gof_omit from 'modelsummary' to clean the table, and additionally, add a row for the mean of the dependent variable without external manipulation.

Arguments

Author

Maintainer: Michael Topper miketopper123@gmail.com

Other contributors:

  • Vincent Arel-Bundock (Some documentation is inherited from 'modelsummary') [copyright holder]

See Also