Rdocumentation
powered by
Learn R Programming
panelsummary (version 0.1.2.1)
shift_means: shifts the custom glance means to above observations and renames
Description
shifts the custom glance means to above observations and renames
Usage
shift_means(df)
Arguments